@@ -353,6 +353,8 @@ def check_dimensions(values, axes):
     axes_shape = []
     for axis in axes:
         if hasattr(axis, "values"):
+            if axis.values.size == 1:
+                axes.values = [axes.values]
             axes_shape.append(len(squeeze(axis.values)))
         else:
             if isinstance(axis.number, int):
